##  Upcoming Changes
The following sections provide an overview of upcoming changes to the GraphQL API and what you need to do to prepare for them.
  * [Stricter Validation of Unconsumed Tokens](https://help.sap.com/docs/leanix/ea/api-updates-graphql-api-changes?locale=en-US&state=PRODUCTION&version=CLOUD#loio275a61aa7a44101480e5e8236acb0351__stricter_validation_of_unconsumed_tokens)
  * [Stricter Validation of Invalid Tokens](https://help.sap.com/docs/leanix/ea/api-updates-graphql-api-changes?locale=en-US&state=PRODUCTION&version=CLOUD#loio275a61aa7a44101480e5e8236acb0351__stricter_validation_of_invalid_tokens)
  * [Stricter Validation of the GraphQL Parsing Token Limit](https://help.sap.com/docs/leanix/ea/api-updates-graphql-api-changes?locale=en-US&state=PRODUCTION&version=CLOUD#loio275a61aa7a44101480e5e8236acb0351__stricter_validation_of_the_graphql_parsing_token_limit)
  * [Stricter Data Type Validation](https://help.sap.com/docs/leanix/ea/api-updates-graphql-api-changes?locale=en-US&state=PRODUCTION&version=CLOUD#loio275a61aa7a44101480e5e8236acb0351__stricter_data_type_validation)


**Tip**
Our interactive GraphiQL interface provides a convenient way to test and validate your queries against the latest schema. Paste your query into the GraphiQL editor and check the query for syntax errors. Syntax errors are highlighted in red. If needed, modify the query to ensure that there are no syntax errors. Then, run the query to ensure that it doesn't result in a warning message.
To learn more about using GraphiQL, see [GraphiQL Tool](https://help.sap.com/docs/leanix/ea/graphql-api?locale=en-US&state=PRODUCTION&version=CLOUD#loio275a6d497a4410149a8bffcc34da11b9__graphiql_tool).
